.. _index:

##################
Welcome to COSMIC!
##################
COSMIC (Compact Object Synthesis and Monte Carlo Investigation Code) is a rapid binary population synthesis suite with a special focus of generating compact binary populations. 

.. raw:: html

    <div class="toms-nav-container" style="margin-bottom:50px;">
        <div class="box" data-href="pages/install.html">Install COSMIC</div>
        <div class="box" data-href="pages/reference_material.html">Configurations and outputs</div>
        <div class="box" data-href="pages/runpop.html">Sampling populations</div>
        <div class="box" data-href="pages/examples.html">Evolving binaries</div>
    </div>

.. toctree::
    :maxdepth: 2
    :hidden:
    
    pages/about
    pages/install
    pages/reference_material
    pages/examples
    pages/runpop
    pages/fixedpop
    pages/cite
    pages/developers

*****************
API documentation
*****************

Please consult these pages for more precise details on the modules in COSMIC:

* :ref:`modindex`
